@@ -97,7 +97,8 @@ GE2014 %>%
 ## ----fig.width = 8-------------------------------------------------------
 library(forcats)
 polls %>%
-filter(MidDate > as.Date("2014-11-20") & !is.na(VotingIntention)) %>%
+    filter(MidDate > as.Date("2014-11-20") & !is.na(VotingIntention)) %>%
+    filter(Party %in% c("National", "Labour", "Green", "NZ First")) %>%
     mutate(Party = fct_reorder(Party, VotingIntention, .desc = TRUE),
            Party = fct_drop(Party)) %>%
     ggplot(aes(x = MidDate, y = VotingIntention, colour = Party, linetype = Pollster)) +
@@ -133,7 +134,7 @@ allocate_seats(votes, electorate = electorate, threshold = 0)$seats_v
 electorates <- c(1,0,0,27,0,1,41,1,1)
 
 polls %>%
-    filter(MidDate > "2014-12-30" & MidDate < "2017-10-1") %>%
+    filter(MidDate > "2014-12-30" & MidDate < "2017-10-1" & Party != "TOP") %>%
     mutate(wt_p = weight_polls(MidDate, method = "pundit"),
            wt_c = weight_polls(MidDate, method = "curia")) %>%
     group_by(Party) %>%
